==> sarm_sdk-1.0.4-py3-none-any.whl: sarm_sdk/models/security_issue.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
SARM SDK 安全问题数据模型

定义安全问题相关的数据结构。
"""

from typing import List, Optional
from pydantic import BaseModel, Field
from datetime import datetime


class SecurityIssueInsert(BaseModel):
    """安全问题创建模型"""
    issue_unique_id: str = Field(..., description="安全问题唯一ID")
    issue_title: str = Field(..., description="安全问题标题")
    issue_level: str = Field(..., description="安全问题级别(critical,high,medium,low)")
    issue_status: str = Field(default="open", description="安全问题状态(open,close)")
    issue_desc: Optional[str] = Field(None, description="安全问题描述")
    solution: Optional[str] = Field(None, description="修复方案")
    discovery_at: Optional[datetime] = Field(None, description="发现时间")
    issue_owner_unique_id: Optional[str] = Field(None, description="负责人唯一ID")
    vuln_unique_id: Optional[List[str]] = Field(default_factory=list, description="关联的漏洞ID列表")
    component_unique_id: Optional[List[str]] = Field(default_factory=list, description="关联的组件ID列表")


class SecurityIssueUpdate(BaseModel):
    """安全问题更新模型"""
    issue_unique_id: str = Field(..., description="安全问题唯一ID")
    issue_owner_unique_id: Optional[str] = Field(None, description="安全问题负责人唯一ID")
    issue_status: Optional[str] = Field(None, description="安全问题处置状态(open, close)")
    issue_title: Optional[str] = Field(None, description="安全问题标题")
    issue_level: Optional[str] = Field(None, description="安全问题级别(critical-严重 high-高 medium-中 low-低)")
    issue_desc: Optional[str] = Field(None, description="安全问题描述")
    solution: Optional[str] = Field(None, description="安全问题修复方案")
    discovery_at: Optional[datetime] = Field(None, description="发现时间")

==> sarm_sdk-1.0.7-py3-none-any.whl: sarm_sdk/models/security_issue.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
SARM SDK 安全问题数据模型

定义安全问题相关的数据结构。
"""

from typing import List, Optional
from pydantic import BaseModel, Field
from datetime import datetime


class SecurityIssueInsert(BaseModel):
    """安全问题创建模型"""
    issue_unique_id: str = Field(..., description="安全问题唯一ID")
    issue_title: str = Field(..., description="安全问题标题")
    issue_level: str = Field(..., description="安全问题级别(critical,high,medium,low)")
    issue_status: str = Field(default="open", description="安全问题状态(open,close)")
    issue_desc: Optional[str] = Field(None, description="安全问题描述")
    solution: Optional[str] = Field(None, description="修复方案")
    discovery_at: Optional[datetime] = Field(None, description="发现时间")
    close_at: Optional[datetime] = Field(None, description="安全问题关闭时间")
    issue_owner_unique_id: Optional[str] = Field(None, description="负责人唯一ID")
    vuln_unique_id: Optional[List[str]] = Field(default_factory=list, description="关联漏洞唯一id列表")
    component_unique_id: Optional[List[str]] = Field(default_factory=list, description="关联成分唯一id列表")


class SecurityIssueUpdate(BaseModel):
    """安全问题更新模型"""
    issue_unique_id: str = Field(..., description="安全问题唯一ID")
    issue_owner_unique_id: Optional[str] = Field(None, description="安全问题负责人唯一ID")
    issue_status: Optional[str] = Field(None, description="安全问题处置状态(open, close)")
    issue_title: Optional[str] = Field(None, description="安全问题标题")
    issue_level: Optional[str] = Field(None, description="安全问题级别(critical-严重 high-高 medium-中 low-低)")
    issue_desc: Optional[str] = Field(None, description="安全问题描述")
    solution: Optional[str] = Field(None, description="安全问题修复方案")
    discovery_at: Optional[datetime] = Field(None, description="发现时间")
    close_at: Optional[datetime] = Field(None, description="安全问题关闭时间")
